# xlns
XLNS: a configurable python package for Logarithmic Number System eXperimentation


# Getting Started

It is recommended to create a python virtual environment for experimentation with the XLNS package. Within that environment, ensure you have the dependencies listed below installed.

Explanatory information about the LNS is in the LNS_Intro.md file.

# Dependencies
numpy

````
pip3 install numpy
````

For some examples, matplotlib is also needed:
````
pip3 install matplotlib
````

You can grab all the dependencies in one go using the requirements file thus:
````
pip install -r requirements.txt
````